@@ -112,6 +112,8 @@ def make_url(d: Date, prefix: str, base_url: str = base_url):
     month = month_str(d)
     period_marker = period_str(d)
     args = base_url, year, month, period_marker, prefix
+    if d == Date(2021, 1):
+        return "https://www.imf.org/-/media/Files/Publications/WEO/WEO-Database/2021/WEOApr2021all.ashx"
     if d >= Date(2020, 2):
         return url_after_2020(*args)
     else:
@@ -175,15 +177,6 @@ def default_filename(d: Date):
     return f"weo_{d.year}_{d.release}.csv"
 
 
-def locate(d, filename: Optional[str] = None, directory: Optional[str] = None):
-    if filename is None:
-        filename = default_filename(d)
-    if directory is None:
-        return filename
-    else:
-        return os.path.normpath(os.path.join(directory, filename))
-
-
 def get_date(year: int, release: Union[int, str]):
     release = get_season(release)
     d = Date(year, release)
@@ -191,6 +184,16 @@ def get_date(year: int, release: Union[int, str]):
     return d
 
 
+def locate(d: Date, filename: Optional[str] = None, directory: Optional[str] = None):
+    if filename is None:
+        filename = default_filename(d)
+    if directory is None:
+        path = filename
+    else:
+        path = os.path.join(directory, filename)
+    return os.path.normpath(path)
+
+
 def curl(path: str, url: str):
     r = requests.get(url, stream=True)
     iterable = r.iter_content(chunk_size=1024)
@@ -202,9 +205,21 @@ def curl(path: str, url: str):
     return path
 
 
+def accept(
+    year: int,
+    release: Union[int, str],
+    filename: Optional[str] = None,
+    directory: Optional[str] = None,
+):
+    d = get_date(year, release)
+    path = locate(d, filename, directory)
+    url = make_url_countries(d)
+    return d, path, url
+
+
 def download(
     year: int,
-    release: int,
+    release: Union[int, str],
     filename: Optional[str] = None,
     directory: str = ".",
     fetch=curl,
